@@ -13,11 +13,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import binascii
 import collections
 import uuid
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.debug import sensitive_variables  # noqa
 
@@ -36,6 +35,7 @@ from trove_dashboard.content.database_clusters \
 from trove_dashboard.content.databases import db_capability
 from trove_dashboard.content.databases.workflows \
     import create_instance
+from trove_dashboard.utils import common as common_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -133,7 +133,7 @@ class LaunchForm(forms.SelfHandlingForm):
         if datastore_field_value:
             datastore, datastore_version = (
                 create_instance.parse_datastore_and_version_text(
-                    binascii.unhexlify(datastore_field_value)))
+                    common_utils.unhexlify(datastore_field_value)))
 
             flavor_field_name = self._build_widget_field_name(
                 datastore, datastore_version)
@@ -236,7 +236,18 @@ class LaunchForm(forms.SelfHandlingForm):
                     # only add to choices if datastore has at least one version
                     version_choices = ()
                     for v in versions:
-                        if hasattr(v, 'active') and not v.active:
+                        # NOTE(zhaochao): troveclient API resources are lazy
+                        # loading objects. When an attribute is not found, the
+                        # get() method of the Manager object will be called
+                        # with the ID of the resource. However for
+                        # datastore_versions, the get() method is expecting two
+                        # arguments: datastore and datastore_version(name), so
+                        # TypeError will be raised as not enough arguments are
+                        # passed. In Python 2.x, hasattr() won't reraise the
+                        # exception(which is not correct), but reraise under
+                        # Python 3(which should be correct).
+                        # Use v.to_dict() to verify the 'active' info instead.
+                        if not v.to_dict().get('active', True):
                             continue
                         selection_text = self._build_datastore_display_text(
                             ds.name, v.name)
@@ -286,7 +297,7 @@ class LaunchForm(forms.SelfHandlingForm):
         # Since the fieldnames cannot contain an uppercase character
         # we generate a hex encoded string representation of the
         # datastore and version as the fieldname
-        return binascii.hexlify(
+        return common_utils.hexlify(
             self._build_datastore_display_text(datastore, datastore_version))
 
     def _insert_datastore_version_fields(self, datastore_flavor_fields):
@@ -299,10 +310,10 @@ class LaunchForm(forms.SelfHandlingForm):
             else:
                 fields_to_restore_at_the_end[k] = v
 
-        for k, v in datastore_flavor_fields.iteritems():
+        for k, v in datastore_flavor_fields.items():
             self.fields[k] = v
 
-        for k in reversed(fields_to_restore_at_the_end.keys()):
+        for k in reversed(list(fields_to_restore_at_the_end.keys())):
             self.fields[k] = fields_to_restore_at_the_end[k]
 
     def _add_attr_to_optional_fields(self, datastore, selection_text):
@@ -330,7 +341,7 @@ class LaunchForm(forms.SelfHandlingForm):
         try:
             datastore, datastore_version = (
                 create_instance.parse_datastore_and_version_text(
-                    binascii.unhexlify(data['datastore'])))
+                    common_utils.unhexlify(data['datastore'])))
 
             flavor_field_name = self._build_widget_field_name(
                 datastore, datastore_version)
@@ -363,7 +374,7 @@ class LaunchForm(forms.SelfHandlingForm):
         except Exception as e:
             redirect = reverse("horizon:project:database_clusters:index")
             exceptions.handle(request,
-                              _('Unable to launch cluster. %s') % e.message,
+                              _('Unable to launch cluster. %s') % e,
                               redirect=redirect)
 
 
@@ -465,7 +476,7 @@ class ClusterAddInstanceForm(forms.SelfHandlingForm):
         except Exception as e:
             redirect = reverse("horizon:project:database_clusters:index")
             exceptions.handle(request,
-                              _('Unable to grow cluster. %s') % e.message,
+                              _('Unable to grow cluster. %s') % e,
                               redirect=redirect)
         return True
 
@@ -488,6 +499,6 @@ class ResetPasswordForm(forms.SelfHandlingForm):
                                         'cluster "%s"') % cluster_id)
         except Exception as e:
             redirect = reverse("horizon:project:database_clusters:index")
-            exceptions.handle(request, _('Unable to reset password. %s') %
-                              e.message, redirect=redirect)
+            exceptions.handle(request, _('Unable to reset password. %s') % e,
+                              redirect=redirect)
         return True
