@@ -111,8 +111,8 @@ class DatabaseTab(tabs.TableTab):
         instance = self.tab_group.kwargs['instance']
         try:
             data = api.trove.database_list(self.request, instance.id)
-            add_instance = lambda d: setattr(d, 'instance', instance)
-            map(add_instance, data)
+            for database in data:
+                setattr(database, 'instance', instance)
         except Exception:
             msg = _('Unable to get databases data.')
             exceptions.handle(self.request, msg)
@@ -178,7 +178,7 @@ class LogsTab(tabs.TableTab):
             return logs
         except Exception as e:
             LOG.exception(
-                _('Unable to retrieve list of logs.\n%s') % e.message)
+                _('Unable to retrieve list of logs.\n%s') % e)
             logs = []
         return logs
 
