@@ -12,10 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import binascii
-
 from django.conf import settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -31,6 +29,7 @@ from oslo_log import log as logging
 
 
 from trove_dashboard import api
+from trove_dashboard.utils import common as common_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -97,7 +96,7 @@ class SetInstanceDetailsAction(workflows.Action):
             self._errors["datastore"] = self.error_class([msg])
         else:
             datastore, datastore_version = parse_datastore_and_version_text(
-                binascii.unhexlify(datastore_and_version))
+                common_utils.unhexlify(datastore_and_version))
             field_name = self._build_flavor_field_name(datastore,
                                                        datastore_version)
             flavor = self.data.get(field_name, None)
@@ -114,7 +113,7 @@ class SetInstanceDetailsAction(workflows.Action):
         datastore_and_version = context["datastore"]
         if datastore_and_version:
             datastore, datastore_version = parse_datastore_and_version_text(
-                binascii.unhexlify(context["datastore"]))
+                common_utils.unhexlify(context["datastore"]))
             field_name = self._build_flavor_field_name(datastore,
                                                        datastore_version)
             flavor = self.data[field_name]
@@ -212,7 +211,12 @@ class SetInstanceDetailsAction(workflows.Action):
                     # only add to choices if datastore has at least one version
                     version_choices = ()
                     for v in versions:
-                        if hasattr(v, 'active') and not v.active:
+                        # NOTE(zhaochao): please refer to the comment about
+                        # the same change for 'populate_datastore_choices'
+                        # of 'LaunchForm' in
+                        # trove_dashboard/content/database_clusters/forms.py
+                        # for details.
+                        if not v.to_dict().get('active', True):
                             continue
                         if self.backup_id:
                             if v.id != backup.datastore['version_id']:
@@ -260,7 +264,7 @@ class SetInstanceDetailsAction(workflows.Action):
         # Since the fieldnames cannot contain an uppercase character
         # we generate a hex encoded string representation of the
         # datastore and version as the fieldname
-        return binascii.hexlify(
+        return common_utils.hexlify(
             self._build_datastore_display_text(datastore, datastore_version))
 
     def _build_flavor_field_name(self, datastore, datastore_version):
@@ -581,7 +585,7 @@ class LaunchInstance(workflows.Workflow):
     def handle(self, request, context):
         try:
             datastore, datastore_version = parse_datastore_and_version_text(
-                binascii.unhexlify(self.context['datastore']))
+                common_utils.unhexlify(self.context['datastore']))
             avail_zone = context.get('availability_zone', None)
             LOG.info("Launching database instance with parameters "
                      "{name=%s, volume=%s, volume_type=%s, flavor=%s, "
